<!-- Layers Menu (c) 2001 Marco Pratesi <pratesi@telug.it> -->

<?
for ($cnt=1; $cnt<=count($tree); $cnt++)
	if (!($tree[$cnt+1][0]<=$tree[$cnt][0])) {
$cellpadding = 10;
$width = $abscissa_step - $cellpadding;
// ormai con $width ci si puo` fare la birra (grazie a Netscoppio 4.x)
?>

<div id="<?=$stripped_tree[$cnt]?>" style="POSITION: absolute; VISIBILITY: hidden;">
<table border=1 cellpadding=0 cellspacing=0 class=nav>
<tr>
<td>
<table border=0 cellpadding=0 cellspacing=<?=$cellpadding?> width="<?=$abscissa_step?>">
<tr>
<td class=normal nowrap>
<b><?=stripslashes($tree[$cnt][1])?></b>
</td>
</tr>
<tr>
<td class=normal nowrap>
<?=$layer[$stripped_tree[$cnt]]?>
</td>
</tr>
</table>
</td>
</tr>
</table>
</div>

<?	} ?>

<script language="JavaScript">
<!--
	gotlayers = 1;	// to avoid stupid errors of Microsoft browsers
	moveLayers();
// -->
</script>

<!-- Layers Menu (c) 2001 Marco Pratesi <pratesi@telug.it> -->
